"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import opentelemetry.proto.common.v1.common_pb2
import opentelemetry.proto.resource.v1.resource_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___SeverityNumber = SeverityNumber

class _SeverityNumber(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
        SeverityNumber.V
    ],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SEVERITY_NUMBER_UNSPECIFIED = SeverityNumber.V(0)
    SEVERITY_NUMBER_TRACE = SeverityNumber.V(1)
    SEVERITY_NUMBER_TRACE2 = SeverityNumber.V(2)
    SEVERITY_NUMBER_TRACE3 = SeverityNumber.V(3)
    SEVERITY_NUMBER_TRACE4 = SeverityNumber.V(4)
    SEVERITY_NUMBER_DEBUG = SeverityNumber.V(5)
    SEVERITY_NUMBER_DEBUG2 = SeverityNumber.V(6)
    SEVERITY_NUMBER_DEBUG3 = SeverityNumber.V(7)
    SEVERITY_NUMBER_DEBUG4 = SeverityNumber.V(8)
    SEVERITY_NUMBER_INFO = SeverityNumber.V(9)
    SEVERITY_NUMBER_INFO2 = SeverityNumber.V(10)
    SEVERITY_NUMBER_INFO3 = SeverityNumber.V(11)
    SEVERITY_NUMBER_INFO4 = SeverityNumber.V(12)
    SEVERITY_NUMBER_WARN = SeverityNumber.V(13)
    SEVERITY_NUMBER_WARN2 = SeverityNumber.V(14)
    SEVERITY_NUMBER_WARN3 = SeverityNumber.V(15)
    SEVERITY_NUMBER_WARN4 = SeverityNumber.V(16)
    SEVERITY_NUMBER_ERROR = SeverityNumber.V(17)
    SEVERITY_NUMBER_ERROR2 = SeverityNumber.V(18)
    SEVERITY_NUMBER_ERROR3 = SeverityNumber.V(19)
    SEVERITY_NUMBER_ERROR4 = SeverityNumber.V(20)
    SEVERITY_NUMBER_FATAL = SeverityNumber.V(21)
    SEVERITY_NUMBER_FATAL2 = SeverityNumber.V(22)
    SEVERITY_NUMBER_FATAL3 = SeverityNumber.V(23)
    SEVERITY_NUMBER_FATAL4 = SeverityNumber.V(24)

class SeverityNumber(metaclass=_SeverityNumber):
    V = typing.NewType("V", builtins.int)

SEVERITY_NUMBER_UNSPECIFIED = SeverityNumber.V(0)
SEVERITY_NUMBER_TRACE = SeverityNumber.V(1)
SEVERITY_NUMBER_TRACE2 = SeverityNumber.V(2)
SEVERITY_NUMBER_TRACE3 = SeverityNumber.V(3)
SEVERITY_NUMBER_TRACE4 = SeverityNumber.V(4)
SEVERITY_NUMBER_DEBUG = SeverityNumber.V(5)
SEVERITY_NUMBER_DEBUG2 = SeverityNumber.V(6)
SEVERITY_NUMBER_DEBUG3 = SeverityNumber.V(7)
SEVERITY_NUMBER_DEBUG4 = SeverityNumber.V(8)
SEVERITY_NUMBER_INFO = SeverityNumber.V(9)
SEVERITY_NUMBER_INFO2 = SeverityNumber.V(10)
SEVERITY_NUMBER_INFO3 = SeverityNumber.V(11)
SEVERITY_NUMBER_INFO4 = SeverityNumber.V(12)
SEVERITY_NUMBER_WARN = SeverityNumber.V(13)
SEVERITY_NUMBER_WARN2 = SeverityNumber.V(14)
SEVERITY_NUMBER_WARN3 = SeverityNumber.V(15)
SEVERITY_NUMBER_WARN4 = SeverityNumber.V(16)
SEVERITY_NUMBER_ERROR = SeverityNumber.V(17)
SEVERITY_NUMBER_ERROR2 = SeverityNumber.V(18)
SEVERITY_NUMBER_ERROR3 = SeverityNumber.V(19)
SEVERITY_NUMBER_ERROR4 = SeverityNumber.V(20)
SEVERITY_NUMBER_FATAL = SeverityNumber.V(21)
SEVERITY_NUMBER_FATAL2 = SeverityNumber.V(22)
SEVERITY_NUMBER_FATAL3 = SeverityNumber.V(23)
SEVERITY_NUMBER_FATAL4 = SeverityNumber.V(24)

global___LogRecordFlags = LogRecordFlags

class _LogRecordFlags(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
        LogRecordFlags.V
    ],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    LOG_RECORD_FLAG_UNSPECIFIED = LogRecordFlags.V(0)
    LOG_RECORD_FLAG_TRACE_FLAGS_MASK = LogRecordFlags.V(255)

class LogRecordFlags(metaclass=_LogRecordFlags):
    V = typing.NewType("V", builtins.int)

LOG_RECORD_FLAG_UNSPECIFIED = LogRecordFlags.V(0)
LOG_RECORD_FLAG_TRACE_FLAGS_MASK = LogRecordFlags.V(255)

class ResourceLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    INSTRUMENTATION_LIBRARY_LOGS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...
    @property
    def resource(
        self,
    ) -> opentelemetry.proto.resource.v1.resource_pb2.Resource: ...
    @property
    def instrumentation_library_logs(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___InstrumentationLibraryLogs
    ]: ...
    def __init__(
        self,
        *,
        resource: typing.Optional[
            opentelemetry.proto.resource.v1.resource_pb2.Resource
        ] = ...,
        instrumentation_library_logs: typing.Optional[
            typing.Iterable[global___InstrumentationLibraryLogs]
        ] = ...,
        schema_url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["resource", b"resource"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "instrumentation_library_logs",
            b"instrumentation_library_logs",
            "resource",
            b"resource",
            "schema_url",
            b"schema_url",
        ],
    ) -> None: ...

global___ResourceLogs = ResourceLogs

class InstrumentationLibraryLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INSTRUMENTATION_LIBRARY_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...
    @property
    def instrumentation_library(
        self,
    ) -> opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary: ...
    @property
    def logs(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LogRecord
    ]: ...
    def __init__(
        self,
        *,
        instrumentation_library: typing.Optional[
            opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary
        ] = ...,
        logs: typing.Optional[typing.Iterable[global___LogRecord]] = ...,
        schema_url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "instrumentation_library", b"instrumentation_library"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "instrumentation_library",
            b"instrumentation_library",
            "logs",
            b"logs",
            "schema_url",
            b"schema_url",
        ],
    ) -> None: ...

global___InstrumentationLibraryLogs = InstrumentationLibraryLogs

class LogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    SEVERITY_NUMBER_FIELD_NUMBER: builtins.int
    SEVERITY_TEXT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DROPPED_ATTRIBUTES_COUNT_FIELD_NUMBER: builtins.int
    FLAGS_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    SPAN_ID_FIELD_NUMBER: builtins.int
    time_unix_nano: builtins.int = ...
    severity_number: global___SeverityNumber.V = ...
    severity_text: typing.Text = ...
    name: typing.Text = ...
    dropped_attributes_count: builtins.int = ...
    flags: builtins.int = ...
    trace_id: builtins.bytes = ...
    span_id: builtins.bytes = ...
    @property
    def body(self) -> opentelemetry.proto.common.v1.common_pb2.AnyValue: ...
    @property
    def attributes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        opentelemetry.proto.common.v1.common_pb2.KeyValue
    ]: ...
    def __init__(
        self,
        *,
        time_unix_nano: builtins.int = ...,
        severity_number: global___SeverityNumber.V = ...,
        severity_text: typing.Text = ...,
        name: typing.Text = ...,
        body: typing.Optional[
            opentelemetry.proto.common.v1.common_pb2.AnyValue
        ] = ...,
        attributes: typing.Optional[
            typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]
        ] = ...,
        dropped_attributes_count: builtins.int = ...,
        flags: builtins.int = ...,
        trace_id: builtins.bytes = ...,
        span_id: builtins.bytes = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["body", b"body"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "attributes",
            b"attributes",
            "body",
            b"body",
            "dropped_attributes_count",
            b"dropped_attributes_count",
            "flags",
            b"flags",
            "name",
            b"name",
            "severity_number",
            b"severity_number",
            "severity_text",
            b"severity_text",
            "span_id",
            b"span_id",
            "time_unix_nano",
            b"time_unix_nano",
            "trace_id",
            b"trace_id",
        ],
    ) -> None: ...

global___LogRecord = LogRecord
