"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import opentelemetry.proto.common.v1.common_pb2
import opentelemetry.proto.resource.v1.resource_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___AggregationTemporality = AggregationTemporality
class _AggregationTemporality(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AggregationTemporality.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    AGGREGATION_TEMPORALITY_UNSPECIFIED = AggregationTemporality.V(0)
    AGGREGATION_TEMPORALITY_DELTA = AggregationTemporality.V(1)
    AGGREGATION_TEMPORALITY_CUMULATIVE = AggregationTemporality.V(2)
class AggregationTemporality(metaclass=_AggregationTemporality):
    V = typing.NewType('V', builtins.int)
AGGREGATION_TEMPORALITY_UNSPECIFIED = AggregationTemporality.V(0)
AGGREGATION_TEMPORALITY_DELTA = AggregationTemporality.V(1)
AGGREGATION_TEMPORALITY_CUMULATIVE = AggregationTemporality.V(2)

class ResourceMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_FIELD_NUMBER: builtins.int
    INSTRUMENTATION_LIBRARY_METRICS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...

    @property
    def resource(self) -> opentelemetry.proto.resource.v1.resource_pb2.Resource: ...

    @property
    def instrumentation_library_metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstrumentationLibraryMetrics]: ...

    def __init__(self,
        *,
        resource : typing.Optional[opentelemetry.proto.resource.v1.resource_pb2.Resource] = ...,
        instrumentation_library_metrics : typing.Optional[typing.Iterable[global___InstrumentationLibraryMetrics]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"resource",b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"instrumentation_library_metrics",b"instrumentation_library_metrics",u"resource",b"resource",u"schema_url",b"schema_url"]) -> None: ...
global___ResourceMetrics = ResourceMetrics

class InstrumentationLibraryMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INSTRUMENTATION_LIBRARY_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    schema_url: typing.Text = ...

    @property
    def instrumentation_library(self) -> opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary: ...

    @property
    def metrics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Metric]: ...

    def __init__(self,
        *,
        instrumentation_library : typing.Optional[opentelemetry.proto.common.v1.common_pb2.InstrumentationLibrary] = ...,
        metrics : typing.Optional[typing.Iterable[global___Metric]] = ...,
        schema_url : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"instrumentation_library",b"instrumentation_library"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"instrumentation_library",b"instrumentation_library",u"metrics",b"metrics",u"schema_url",b"schema_url"]) -> None: ...
global___InstrumentationLibraryMetrics = InstrumentationLibraryMetrics

class Metric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    INT_GAUGE_FIELD_NUMBER: builtins.int
    GAUGE_FIELD_NUMBER: builtins.int
    INT_SUM_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    INT_HISTOGRAM_FIELD_NUMBER: builtins.int
    HISTOGRAM_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    description: typing.Text = ...
    unit: typing.Text = ...

    @property
    def int_gauge(self) -> global___IntGauge: ...

    @property
    def gauge(self) -> global___Gauge: ...

    @property
    def int_sum(self) -> global___IntSum: ...

    @property
    def sum(self) -> global___Sum: ...

    @property
    def int_histogram(self) -> global___IntHistogram: ...

    @property
    def histogram(self) -> global___Histogram: ...

    @property
    def summary(self) -> global___Summary: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        description : typing.Text = ...,
        unit : typing.Text = ...,
        int_gauge : typing.Optional[global___IntGauge] = ...,
        gauge : typing.Optional[global___Gauge] = ...,
        int_sum : typing.Optional[global___IntSum] = ...,
        sum : typing.Optional[global___Sum] = ...,
        int_histogram : typing.Optional[global___IntHistogram] = ...,
        histogram : typing.Optional[global___Histogram] = ...,
        summary : typing.Optional[global___Summary] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"gauge",b"gauge",u"histogram",b"histogram",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum",u"sum",b"sum",u"summary",b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"description",b"description",u"gauge",b"gauge",u"histogram",b"histogram",u"int_gauge",b"int_gauge",u"int_histogram",b"int_histogram",u"int_sum",b"int_sum",u"name",b"name",u"sum",b"sum",u"summary",b"summary",u"unit",b"unit"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing_extensions.Literal["int_gauge","gauge","int_sum","sum","int_histogram","histogram","summary"]: ...
global___Metric = Metric

class IntGauge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___IntDataPoint]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_points",b"data_points"]) -> None: ...
global___IntGauge = IntGauge

class Gauge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NumberDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___NumberDataPoint]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_points",b"data_points"]) -> None: ...
global___Gauge = Gauge

class IntSum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int
    AGGREGATION_TEMPORALITY_FIELD_NUMBER: builtins.int
    IS_MONOTONIC_FIELD_NUMBER: builtins.int
    aggregation_temporality: global___AggregationTemporality.V = ...
    is_monotonic: builtins.bool = ...

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___IntDataPoint]] = ...,
        aggregation_temporality : global___AggregationTemporality.V = ...,
        is_monotonic : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
global___IntSum = IntSum

class Sum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int
    AGGREGATION_TEMPORALITY_FIELD_NUMBER: builtins.int
    IS_MONOTONIC_FIELD_NUMBER: builtins.int
    aggregation_temporality: global___AggregationTemporality.V = ...
    is_monotonic: builtins.bool = ...

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NumberDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___NumberDataPoint]] = ...,
        aggregation_temporality : global___AggregationTemporality.V = ...,
        is_monotonic : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points",u"is_monotonic",b"is_monotonic"]) -> None: ...
global___Sum = Sum

class IntHistogram(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int
    AGGREGATION_TEMPORALITY_FIELD_NUMBER: builtins.int
    aggregation_temporality: global___AggregationTemporality.V = ...

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntHistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___IntHistogramDataPoint]] = ...,
        aggregation_temporality : global___AggregationTemporality.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
global___IntHistogram = IntHistogram

class Histogram(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int
    AGGREGATION_TEMPORALITY_FIELD_NUMBER: builtins.int
    aggregation_temporality: global___AggregationTemporality.V = ...

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HistogramDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___HistogramDataPoint]] = ...,
        aggregation_temporality : global___AggregationTemporality.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aggregation_temporality",b"aggregation_temporality",u"data_points",b"data_points"]) -> None: ...
global___Histogram = Histogram

class Summary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_POINTS_FIELD_NUMBER: builtins.int

    @property
    def data_points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SummaryDataPoint]: ...

    def __init__(self,
        *,
        data_points : typing.Optional[typing.Iterable[global___SummaryDataPoint]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data_points",b"data_points"]) -> None: ...
global___Summary = Summary

class IntDataPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LABELS_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    EXEMPLARS_FIELD_NUMBER: builtins.int
    start_time_unix_nano: builtins.int = ...
    time_unix_nano: builtins.int = ...
    value: builtins.int = ...

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    @property
    def exemplars(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        start_time_unix_nano : builtins.int = ...,
        time_unix_nano : builtins.int = ...,
        value : builtins.int = ...,
        exemplars : typing.Optional[typing.Iterable[global___IntExemplar]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
global___IntDataPoint = IntDataPoint

class NumberDataPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    AS_DOUBLE_FIELD_NUMBER: builtins.int
    AS_INT_FIELD_NUMBER: builtins.int
    EXEMPLARS_FIELD_NUMBER: builtins.int
    start_time_unix_nano: builtins.int = ...
    time_unix_nano: builtins.int = ...
    as_double: builtins.float = ...
    as_int: builtins.int = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    @property
    def exemplars(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exemplar]: ...

    def __init__(self,
        *,
        attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        start_time_unix_nano : builtins.int = ...,
        time_unix_nano : builtins.int = ...,
        as_double : builtins.float = ...,
        as_int : builtins.int = ...,
        exemplars : typing.Optional[typing.Iterable[global___Exemplar]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"as_double",b"as_double",u"as_int",b"as_int",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"as_double",b"as_double",u"as_int",b"as_int",u"attributes",b"attributes",u"exemplars",b"exemplars",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"time_unix_nano",b"time_unix_nano",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"value",b"value"]) -> typing_extensions.Literal["as_double","as_int"]: ...
global___NumberDataPoint = NumberDataPoint

class IntHistogramDataPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LABELS_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    BUCKET_COUNTS_FIELD_NUMBER: builtins.int
    EXPLICIT_BOUNDS_FIELD_NUMBER: builtins.int
    EXEMPLARS_FIELD_NUMBER: builtins.int
    start_time_unix_nano: builtins.int = ...
    time_unix_nano: builtins.int = ...
    count: builtins.int = ...
    sum: builtins.int = ...
    bucket_counts: google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int] = ...
    explicit_bounds: google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float] = ...

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    @property
    def exemplars(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IntExemplar]: ...

    def __init__(self,
        *,
        labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        start_time_unix_nano : builtins.int = ...,
        time_unix_nano : builtins.int = ...,
        count : builtins.int = ...,
        sum : builtins.int = ...,
        bucket_counts : typing.Optional[typing.Iterable[builtins.int]] = ...,
        explicit_bounds : typing.Optional[typing.Iterable[builtins.float]] = ...,
        exemplars : typing.Optional[typing.Iterable[global___IntExemplar]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
global___IntHistogramDataPoint = IntHistogramDataPoint

class HistogramDataPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    BUCKET_COUNTS_FIELD_NUMBER: builtins.int
    EXPLICIT_BOUNDS_FIELD_NUMBER: builtins.int
    EXEMPLARS_FIELD_NUMBER: builtins.int
    start_time_unix_nano: builtins.int = ...
    time_unix_nano: builtins.int = ...
    count: builtins.int = ...
    sum: builtins.float = ...
    bucket_counts: google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int] = ...
    explicit_bounds: google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float] = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    @property
    def exemplars(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exemplar]: ...

    def __init__(self,
        *,
        attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        start_time_unix_nano : builtins.int = ...,
        time_unix_nano : builtins.int = ...,
        count : builtins.int = ...,
        sum : builtins.float = ...,
        bucket_counts : typing.Optional[typing.Iterable[builtins.int]] = ...,
        explicit_bounds : typing.Optional[typing.Iterable[builtins.float]] = ...,
        exemplars : typing.Optional[typing.Iterable[global___Exemplar]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"bucket_counts",b"bucket_counts",u"count",b"count",u"exemplars",b"exemplars",u"explicit_bounds",b"explicit_bounds",u"labels",b"labels",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
global___HistogramDataPoint = HistogramDataPoint

class SummaryDataPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ValueAtQuantile(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        QUANTILE_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        quantile: builtins.float = ...
        value: builtins.float = ...

        def __init__(self,
            *,
            quantile : builtins.float = ...,
            value : builtins.float = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"quantile",b"quantile",u"value",b"value"]) -> None: ...

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    START_TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    QUANTILE_VALUES_FIELD_NUMBER: builtins.int
    start_time_unix_nano: builtins.int = ...
    time_unix_nano: builtins.int = ...
    count: builtins.int = ...
    sum: builtins.float = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    @property
    def quantile_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SummaryDataPoint.ValueAtQuantile]: ...

    def __init__(self,
        *,
        attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        start_time_unix_nano : builtins.int = ...,
        time_unix_nano : builtins.int = ...,
        count : builtins.int = ...,
        sum : builtins.float = ...,
        quantile_values : typing.Optional[typing.Iterable[global___SummaryDataPoint.ValueAtQuantile]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"count",b"count",u"labels",b"labels",u"quantile_values",b"quantile_values",u"start_time_unix_nano",b"start_time_unix_nano",u"sum",b"sum",u"time_unix_nano",b"time_unix_nano"]) -> None: ...
global___SummaryDataPoint = SummaryDataPoint

class IntExemplar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FILTERED_LABELS_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    SPAN_ID_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    time_unix_nano: builtins.int = ...
    value: builtins.int = ...
    span_id: builtins.bytes = ...
    trace_id: builtins.bytes = ...

    @property
    def filtered_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        time_unix_nano : builtins.int = ...,
        value : builtins.int = ...,
        span_id : builtins.bytes = ...,
        trace_id : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
global___IntExemplar = IntExemplar

class Exemplar(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FILTERED_ATTRIBUTES_FIELD_NUMBER: builtins.int
    FILTERED_LABELS_FIELD_NUMBER: builtins.int
    TIME_UNIX_NANO_FIELD_NUMBER: builtins.int
    AS_DOUBLE_FIELD_NUMBER: builtins.int
    AS_INT_FIELD_NUMBER: builtins.int
    SPAN_ID_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    time_unix_nano: builtins.int = ...
    as_double: builtins.float = ...
    as_int: builtins.int = ...
    span_id: builtins.bytes = ...
    trace_id: builtins.bytes = ...

    @property
    def filtered_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.KeyValue]: ...

    @property
    def filtered_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]: ...

    def __init__(self,
        *,
        filtered_attributes : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.KeyValue]] = ...,
        filtered_labels : typing.Optional[typing.Iterable[opentelemetry.proto.common.v1.common_pb2.StringKeyValue]] = ...,
        time_unix_nano : builtins.int = ...,
        as_double : builtins.float = ...,
        as_int : builtins.int = ...,
        span_id : builtins.bytes = ...,
        trace_id : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"as_double",b"as_double",u"as_int",b"as_int",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"as_double",b"as_double",u"as_int",b"as_int",u"filtered_attributes",b"filtered_attributes",u"filtered_labels",b"filtered_labels",u"span_id",b"span_id",u"time_unix_nano",b"time_unix_nano",u"trace_id",b"trace_id",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"value",b"value"]) -> typing_extensions.Literal["as_double","as_int"]: ...
global___Exemplar = Exemplar
